@@ -88,6 +88,34 @@ sub template_email : Global('template_email') {
     }
 }
 
+sub template_email_single : Global('template_email_single') {
+    my ($self, $c, @args) = @_;
+
+    $c->stash->{time} = $c->req->params->{time} || time;
+
+    $c->stash->{email} = {
+        to           => 'test-email@example.com',
+        from         => 'no-reply@example.com',
+        subject      => 'Just a test',
+        content_type => 'multipart/alternative',
+        templates =>  {
+            view            => 'TT',
+            template        => 'text_html/test.tt',
+            content_type    => 'text/html',
+        },
+        
+    };
+
+    $c->forward('TestApp::View::Email::Template');    
+
+    if ( scalar( @{ $c->error } ) ) {
+        $c->res->status(500);
+        $c->res->body('Template Email Failed');
+    } else {
+        $c->res->body('Template Email Ok');
+    }
+}
+
 sub template_email_utf8 : Global('template_email_utf8') {
     my ($self, $c, @args) = @_;
 
